@@ -289,7 +289,7 @@ class MultisiteConfig(flow.Object):
 
     current_site_name = flow.Computed(cached=True)
     root_dir = flow.Computed(cached=True)
-    exchange_site_name = flow.Param("default", ExchangeSiteChoiceValue).watched().ui(
+    exchange_site_name = flow.Param("default_exchange", ExchangeSiteChoiceValue).watched().ui(
         editable=False
     )
     working_sites = flow.Child(WorkingSites).ui(label="Working sites")
