@@ -7,7 +7,6 @@ from collections import defaultdict
 from kabaret import flow
 
 from .maputils import SimpleCreateAction
-from .site import RequestingSiteChoiceValue
 
 
 class DependencyTemplate(flow.Object):
@@ -22,7 +21,12 @@ class DependencyTemplate(flow.Object):
         return self.defaults.get()
 
     def get_dependency_files(self, name):
-        return self.get_dependencies()[name]
+        deps = self.get_dependencies()[name]
+        
+        if 'files' in deps:
+            return deps['files']
+        
+        return deps
 
     def get_asset_files(self, asset_name):
         kitsu_bindings = self.root().project().kitsu_bindings()
@@ -416,6 +420,7 @@ class DependencyItem(flow.Object):
     source_site = flow.Computed(store_value=False)
     comment = flow.Computed(store_value=False)
     path = flow.Computed(store_value=False)
+    in_breakdown = flow.Computed(store_value=False)
     is_alien = flow.Computed(store_value=False)
 
     def compute_child_value(self, child_value):
@@ -468,8 +473,8 @@ class DependencyItemFile(DependencyItem):
             requesting_site_name = self.root().project().get_current_site().name()
         
         request_action = revision.request_as
-        request_action.requesting_site_name.set(requesting_site_name)
-        request_action.requested_site_name.set(self.source_site.get())
+        request_action.target_site.set(requesting_site_name)
+        request_action.source_site.set(self.source_site.get())
         request_action.run(None)
 
     def compute_child_value(self, child_value):
@@ -496,6 +501,8 @@ class DependencyItemFile(DependencyItem):
             self.comment.set(self._get_comment(data))
         elif child_value is self.path:
             self.path.set(data['path'])
+        elif child_value is self.in_breakdown:
+            self.in_breakdown.set(data['in_breakdown'])
         elif child_value is self.is_alien:
             self.is_alien.set(data['is_alien'])
 
