@@ -156,6 +156,10 @@ class KitsuAPIWrapper(flow.Object):
         
         return task['task_status']['name']
     
+    def get_shot_task_types(self):
+        types = gazu.task.all_task_types()
+        return [t['name'] for t in types if t['for_shots']]
+    
     def get_user(self, project_user_name=None):
         if project_user_name is None:
             project_user_name = self.root().project().get_user()
