@@ -15,7 +15,7 @@ from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 from kabaret.subprocess_manager.flow import RunAction
 from .dependency import get_dependencies
 
-from .maputils import ItemMap, CreateGenericAction, ClearMapAction, RemoveGenericAction
+from .maputils import ItemMap, CreateGenericAction, ClearMapAction, RemoveGenericAction, SimpleCreateAction
 from libreflow.baseflow.runners import Runner, PythonRunner
 
 
@@ -739,6 +739,86 @@ class ClearQueueAction(flow.Action):
         queue.touch()
 
 
+class RemoveEnvironmentVariableAction(flow.Action):
+
+    _variable = flow.Parent().ui(hidden=True)
+    _collection = flow.Parent(2).ui(hidden=True)
+
+    def get_buttons(self):
+        return ['Confirm', 'Cancel']
+
+    def run(self, button):
+        if button == 'Cancel':
+            return
+
+        self._collection.touch()
+        self._collection.remove(self._variable.name())
+
+
+class EnvironmentVariable(flow.Object):
+
+    vars_collection = flow.Parent()
+    variable = flow.Param("")
+    value = flow.Param("")
+    remove_variable = flow.Child(RemoveEnvironmentVariableAction)
+
+
+class AddEnvironmentVariableAction(flow.Action):
+
+    _vars_collection = flow.Parent().ui(hidden=True)
+    variable = flow.Param("")
+    value = flow.Param("")
+
+    def get_buttons(self):
+        return ['Create', 'Cancel']
+
+    def run(self, button):
+        var_name = self.variable.get().replace(' ', '_').upper()
+
+        if button == 'Cancel':
+            self.variable.set("")
+            self.value.set("")
+            return
+
+        elif (len(var_name) == 0) or (len(self.value.get()) == 0) or (self._vars_collection.has_mapped_name(var_name)):
+            self.variable.set("")
+            self.value.set("")
+            return
+
+        else:
+            new_var = self._vars_collection.add(var_name)
+            
+            new_var.variable.set(var_name)
+            new_var.value.set(self.value.get())
+            self.variable.set("")
+            self.value.set("")
+            self._vars_collection.touch()
+
+
+class SiteEnvironment(flow.Map):
+    
+    add_environment_variable = flow.Child(AddEnvironmentVariableAction)
+
+    @classmethod
+    def mapped_type(cls):
+        return EnvironmentVariable
+
+
+    def columns(self):
+        return ['Variable', 'Value']
+
+    def _fill_row_cells(self, row, item):
+        row['Variable'] = item.variable.get()
+        row['Value'] = item.value.get()
+
+
+class SiteJobsPoolNames(flow.values.ChoiceValue):
+    
+    def choices(self):
+        site = self.root().project().get_current_site()
+        return ['default'] + site.pool_names.get()
+
+
 class WorkingSite(Site):
     
     site_type = flow.Param("Studio", StaticSiteTypeChoices)
@@ -766,6 +846,7 @@ class WorkingSite(Site):
         label="Show job queue"
     )
     clear_queue = flow.Child(ClearQueueAction)
+    site_environment = flow.Child(SiteEnvironment)
 
     def compute_child_value(self, child_value):
         if child_value is self.root_folder:
